@@ -12,6 +12,15 @@ class Prop:
     description: str
 
 
+@dataclass
+class FuncProp:
+    """Function parameter for a step."""
+
+    func: Callable
+    params: Dict
+    description: str
+
+
 @dataclass
 class Step:
     """A Step of the flow."""
